# Saki

![](https://www.beardsleyzoo.org/uploads/1/2/4/2/124214186/245_orig.jpg)

## Desciption

Saki is an alternative of the cat and nano command line tools.


## Install 

### Windows
Go to cmd or powershell and run
```
pip install windows-curses
```
then run
```
pip install saki
```

### Mac/Linux
```
pip install saki
```
or
```
pip3 install saki
```


## Links

Github - https://github.com/Luke-Pitstick/saki

PyPi - https://pypi.org/project/saki/


